/*
  wrapper class for a toolkit signal mechanism
  Copyright (C) 1998  Martin Vogt

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation.

  For more information look at the file COPYRIGHT in this package

 */





#ifndef __NOTIFYMAINTHREAD_H
#define __NOTIFYMAINTHREAD_H

#include <signal/qt/notifyMainThreadClient.h>

extern "C" {
#include <unistd.h>
	   }

#include <qobject.h>
#include <qsocknot.h> 
#include <pthread.h>



/**
   The intention of this class is to create a wrapper class
   for the different gui toolkits. (eg: QT,Gtk--)
   <p>
   Most modern gui toolkit have a main loop and generate events
   which are delivered to the widgets.
   And all modern toolkits are not thread safe. But the
   frontend classes make heavily use of thread. Thus there
   must be a mechanism (thread safe!) which sends the gui a signal.
   <p>
   The interface between thread<->gui should be as simple as possible.
   
*/


class NotifyMainThread : public QObject {
 Q_OBJECT

  int fd[2];

  char msgId;
  int delivered;

  NotifyMainThreadClient* client;
  QSocketNotifier* sn;
  
  pthread_cond_t deliverCond;
  pthread_mutex_t deliverMut;
  

 public:
  NotifyMainThread(NotifyMainThreadClient* client);
  ~NotifyMainThread();

  void sendNotify(char msgId);      // called by thread

 public slots:
  void clientNotify();    // this method is called by the main/gui-thread

};
#endif
